#
# spec file for package python-importlib-metadata
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%if %{python3_version_nodots} >= 38
%define skip_python3 1
%endif
%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
Name:           python-importlib-metadata%{psuffix}
Version:        1.5.0
Release:        3.3.5
Summary:        Tool to read metadata from Python packages
License:        Apache-2.0
URL:            https://gitlab.com/python-devs/importlib_metadata
Source:         https://files.pythonhosted.org/packages/source/i/importlib_metadata/importlib_metadata-%{version}.tar.gz
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-zipp >= 0.5
Provides:       python-importlib_metadata = %{version}
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module packaging}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pyfakefs}
BuildRequires:  %{python_module wheel}
BuildRequires:  %{python_module zipp >= 0.5}
BuildRequires:  python-importlib_resources
BuildRequires:  python2-configparser >= 3.5
BuildRequires:  python2-contextlib2
%if %{?suse_version} <= 1500
BuildRequires:  python3-importlib_resources
%endif
%if 0%{?suse_version} < 1500
BuildRequires:  %{python_module pathlib2}
%else
BuildRequires:  python-pathlib2
%endif
%endif
%ifpython2
Requires:       python-configparser >= 3.5
Requires:       python-contextlib2
Requires:       python-pathlib2
%endif
%python_subpackages

%description
importlib_metadata is a library to access the metadata for a Python
package.  It is intended to be ported to Python 3.8.

%prep
%setup -q -n importlib_metadata-%{version}

%build
%python_build

%install
%if !%{with test}
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%check
%if %{with test}
%python_exec -m unittest discover -v
%endif

%if !%{with test}
%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/*
%endif

%changelog
* Sun Mar  8 2020 tchvatal@suse.com
- Switch to multibuild in order to avoid buildcycles
* Fri Feb 28 2020 dmueller@suse.com
- update to 1.5.0:
  * Additional performance optimizations in FastPath now
    saves an additional 20%% on a typical call.
  * Correct for issue where PyOxidizer finder has no
    ``__module__`` attribute. Closes #110.
* Fri Jan 17 2020 mcalabkova@suse.com
- update to 1.4.0
  * Renamed package parameter to distribution_name.
  * For better compatibility with the stdlib implementation and to
    avoid the same distributions being discovered by the stdlib
    and backport implementations, the backport now disables the
    stdlib DistributionFinder during initialization (import time).
  * Project adopts semver for versioning.
  * EntryPoints are now pickleable.
  * Dropped support for Python 3.4.
  * Fixed repr(EntryPoint) on PyPy.
  * Repaired project metadata to correctly declare the python_requires directive.
  * Through careful optimization, distribution() is 3-4x faster.
  * When searching through sys.path, if any error occurs attempting
    to list a path entry, that entry is skipped, making the system
    much more lenient to errors.
* Wed Sep 11 2019 tchvatal@suse.com
- Update to 0.21:
  * various minor fixes
* Wed Aug  7 2019 mimi.vx@gmail.com
- update to 0.19
  * restrain over-eager egg metadata resolution.
  * Add support for entry points with colons in the name.
  * Parse entry points case sensitively.
  * Add a version constraint on the backport configparser package
* Wed Jul 31 2019 tchvatal@suse.com
- This package is part of python 3.8 and we don't need to build
  it there
- Do not require importlib_resources on python3.7 where it is
  part of core python
* Tue Jul  9 2019 tchvatal@suse.com
- Fixup the requires for the SLE-12 build
* Tue Jul  9 2019 adrian.glaubitz@suse.com
- Enable python-pathlib2 build dependency for suse_version < 1500 to fix SLE-12 build
* Mon Jun  3 2019 tchvatal@suse.com
- Remove do-not-test-pip.patch as it seems no longer needed
* Mon Jun  3 2019 tchvatal@suse.com
- Update to 0.17:
  * Don't crash if there exists an EGG-INFO directory on sys.path.
  * Update docstrings to match PEP 8. Closes #63.
  * Merged modules into one module. Closes #62.
  * Add support for eggs.  !65; Closes #19.
  * Support generic zip files (not just wheels).  Closes #59
  * Support zip files with multiple distributions in them.  Closes #60
  * Fully expose the public API in importlib_metadata.__all__.
  * The Distribution ABC is now officially part of the public API.
  * Fixed support for older single file egg-info formats.  Closes #43.
  * Fixed a testing bug when $CWD has spaces in the path.  Closes #50.
  * Fixed issue where entry points without an attribute would raise an Exception.
  * Removed unused name parameter from entry_points(). Closes #44.
  * DistributionFinder classes must now be instantiated before being placed on sys.meta_path.
* Tue Feb 26 2019 tchvatal@suse.com
- Add missing setuptools_scm dependency to fix generated egg.info
* Tue Feb 26 2019 tchvatal@suse.com
- Some packages request importlib_metadata to ease living provide
  this symbol too
* Wed Feb  6 2019 alarrosa@suse.com
- Add do-not-test-pip.patch so tests depending on pip are not used
  (they fail when the tests are run without tox)
* Thu Jan 31 2019 tchvatal@suse.com
- Initial commit, needed by pygments-pytest
